@@ -10,11 +10,13 @@ from typing import Any, List, Optional, Union
 from econml.solutions.causal_analysis import CausalAnalysis
 from pathlib import Path
 
-from responsibleai._internal.constants import ManagerNames
+from responsibleai._data_validations import validate_train_test_categories
+from responsibleai._internal.constants import (
+    ManagerNames, SerializationAttributes)
 from responsibleai._managers.base_manager import BaseManager
 from responsibleai.exceptions import UserConfigValidationException
 from responsibleai._tools.causal.causal_constants import (
-    DefaultParams, ModelTypes, ResultAttributes, SerializationAttributes)
+    DefaultParams, ModelTypes, ResultAttributes)
 from responsibleai._tools.causal.causal_config import CausalConfig
 from responsibleai._tools.causal.causal_result import CausalResult
 from responsibleai.modelanalysis.constants import ModelTask
@@ -23,8 +25,14 @@ from responsibleai.modelanalysis.constants import ModelTask
 class CausalManager(BaseManager):
     """Manager for causal analysis."""
 
-    def __init__(self, train, test, target_column, task_type,
-                 categorical_features):
+    def __init__(
+        self,
+        train: pd.DataFrame,
+        test: pd.DataFrame,
+        target_column: str,
+        task_type: str,
+        categorical_features: Optional[List[str]]
+    ):
         """Construct a CausalManager for generating causal analyses
            from a dataset.
         :param train: Dataset on which to compute global causal effects
@@ -44,7 +52,11 @@ class CausalManager(BaseManager):
         self._test = test
         self._target_column = target_column
         self._task_type = task_type
+
         self._categorical_features = categorical_features
+        if categorical_features is None:
+            self._categorical_features = []
+
         self._results = []
 
     def add(
@@ -94,8 +106,8 @@ class CausalManager(BaseManager):
             value to indicate a constant cost of applying that treatment or
             an array indicating the cost for each sample. If the treatment
             is a discrete treatment, then the array for that feature should
-            be two dimensional wih the first dimension representing samples
-            and t second representing the difference in cost between the
+            be two dimensional with the first dimension representing samples
+            and the second representing the difference in cost between the
             non-default values and the default value.
         :type treatment_cost: None, List of float or array
         :param min_tree_leaf_samples: Minimum number of samples per leaf
@@ -143,21 +155,20 @@ class CausalManager(BaseManager):
                        f"got {nuisance_model}")
             raise UserConfigValidationException(message)
 
-        categoricals = self._categorical_features
-        if categoricals is None:
-            categoricals = []
-
         X_train = self._train.drop([self._target_column], axis=1)
         X_test = self._test.drop([self._target_column], axis=1)
         y_train = self._train[self._target_column].values.ravel()
 
-        self._validate_train_test_categories(
-            X_train, X_test, categoricals)
+        validate_train_test_categories(
+            train_data=self._train,
+            test_data=self._test,
+            rai_compute_type='Causal analysis',
+            categoricals=self._categorical_features)
 
         is_classification = self._task_type == ModelTask.CLASSIFICATION
         analysis = CausalAnalysis(
             treatment_features,
-            categoricals,
+            self._categorical_features,
             heterogeneity_inds=heterogeneity_features,
             classification=is_classification,
             nuisance_models=nuisance_model,
@@ -188,6 +199,7 @@ class CausalManager(BaseManager):
             categories=categories,
             verbose=verbose,
             random_state=random_state,
+            categorical_features=self._categorical_features,
         )
 
         result.causal_analysis = analysis
@@ -231,27 +243,6 @@ class CausalManager(BaseManager):
         self._results.append(result)
         return result
 
-    def _validate_train_test_categories(
-        self,
-        X_train: pd.DataFrame,
-        X_test: pd.DataFrame,
-        categoricals,
-    ):
-        discovered = {}
-        for column in X_train.columns:
-            if column in categoricals:
-                train_unique = np.unique(X_train[column])
-                test_unique = np.unique(X_test[column])
-                difference = np.setdiff1d(test_unique, train_unique)
-                if difference.shape[0] != 0:
-                    discovered[column] = difference.tolist()
-        if len(discovered) > 0:
-            message = ("Causal analysis requires that every category of "
-                       "categorical features present in the test data "
-                       "be also present in the train data. "
-                       "Categories missing from train data: {}")
-            raise UserConfigValidationException(message.format(discovered))
-
     def _fit_causal_analysis(
         self,
         causal_analysis,
@@ -351,7 +342,7 @@ class CausalManager(BaseManager):
         causal_dir.mkdir(parents=True, exist_ok=True)
 
         # Save results to disk
-        results_path = causal_dir / SerializationAttributes.RESULTS
+        results_path = causal_dir / SerializationAttributes.RESULTS_DIRECTORY
         results_path.mkdir(parents=True, exist_ok=True)
         for result in self._results:
             result_path = results_path / result.id
@@ -370,7 +361,7 @@ class CausalManager(BaseManager):
         causal_dir = Path(path)
 
         # Rehydrate results
-        results_path = causal_dir / SerializationAttributes.RESULTS
+        results_path = causal_dir / SerializationAttributes.RESULTS_DIRECTORY
         paths = results_path.resolve().glob('*')
         this.__dict__['_results'] = [CausalResult.load(p) for p in paths]
 
