@@ -7,6 +7,7 @@ import dice_ml
 from dice_ml import Dice
 import numpy as np
 
+from responsibleai._data_validations import validate_train_test_categories
 from responsibleai._internal.constants import ManagerNames
 from responsibleai._managers.base_manager import BaseManager
 from responsibleai._config.base_config import BaseConfig
@@ -110,6 +111,12 @@ class CounterfactualManager(BaseManager):
                 'Model is required for counterfactual example generation and '
                 'feature importances')
 
+        validate_train_test_categories(
+            train_data=self._train,
+            test_data=self._test,
+            rai_compute_type='Counterfactual example generation',
+            categoricals=self._categorical_features)
+
         to_vary = new_counterfactual_config.features_to_vary
         if to_vary != 'all':
             difference_set = set(to_vary) - set(self._train.columns)
