@@ -72,7 +72,8 @@ class ModelAnalysis(object):
 
     def __init__(self, model, train, test, target_column,
                  task_type, categorical_features=None, train_labels=None,
-                 serializer=None):
+                 serializer=None,
+                 maximum_rows_for_test: int = 5000):
         """Defines the top-level Model Analysis API.
         Use ModelAnalysis to analyze errors, explain the most important
         features, compute counterfactuals and run causal analysis in a
@@ -99,13 +100,17 @@ class ModelAnalysis(object):
             method returns a dictionary state and load method returns the
             model.
         :type serializer: object
+        :param maximum_rows_for_test: Limit on size of test data
+            (for performance reasons)
+        :type maximum_rows_for_test: int
         """
         self._validate_model_analysis_input_parameters(
             model=model, train=train, test=test,
             target_column=target_column, task_type=task_type,
             categorical_features=categorical_features,
             train_labels=train_labels,
-            serializer=serializer)
+            serializer=serializer,
+            maximum_rows_for_test=maximum_rows_for_test)
         self.model = model
         self.train = train
         self.test = test
@@ -156,8 +161,9 @@ class ModelAnalysis(object):
 
     def _validate_model_analysis_input_parameters(
             self, model, train, test, target_column,
-            task_type, categorical_features=None, train_labels=None,
-            serializer=None):
+            task_type, categorical_features, train_labels,
+            serializer,
+            maximum_rows_for_test: int):
         """
         Validate the inputs for ModelAnalysis class.
 
@@ -183,6 +189,9 @@ class ModelAnalysis(object):
             method returns a dictionary state and load method returns the
             model.
         :type serializer: object
+        :param maximum_rows_for_test: Limit on size of test data
+            (for performance reasons)
+        :type maximum_rows_for_test: int
         """
 
         valid_tasks = [
@@ -216,6 +225,16 @@ class ModelAnalysis(object):
                     'The serializer should be serializable via pickle')
 
         if isinstance(train, pd.DataFrame) and isinstance(test, pd.DataFrame):
+            if test.shape[0] > maximum_rows_for_test:
+                msg_fmt = 'The test data has {0} rows, ' +\
+                    'but limit is set to {1} rows. ' +\
+                    'Please resample the test data or ' +\
+                    'adjust maximum_rows_for_test'
+                raise UserConfigValidationException(
+                    msg_fmt.format(
+                        test.shape[0], maximum_rows_for_test)
+                )
+
             if len(set(train.columns) - set(test.columns)) != 0 or \
                     len(set(test.columns) - set(train.columns)):
                 raise UserConfigValidationException(
@@ -263,12 +282,14 @@ class ModelAnalysis(object):
                         'target (test data) do not match')
 
             if model is not None:
+                # Pick one row from train and test data
+                small_train_data = train.iloc[0:1].drop(
+                    [target_column], axis=1)
+                small_test_data = test.iloc[0:1].drop(
+                    [target_column], axis=1)
+
                 # Run predict() of the model
                 try:
-                    small_train_data = train.iloc[0:1].drop(
-                        [target_column], axis=1)
-                    small_test_data = test.iloc[0:1].drop(
-                        [target_column], axis=1)
                     model.predict(small_train_data)
                     model.predict(small_test_data)
                 except Exception:
@@ -280,10 +301,6 @@ class ModelAnalysis(object):
                 # Run predict_proba() of the model
                 if task_type == ModelTask.CLASSIFICATION:
                     try:
-                        small_train_data = train.iloc[0:1].drop(
-                            [target_column], axis=1)
-                        small_test_data = test.iloc[0:1].drop(
-                            [target_column], axis=1)
                         model.predict_proba(small_train_data)
                         model.predict_proba(small_test_data)
                     except Exception:
