@@ -48,7 +48,7 @@ def create_sklearn_svm_classifier(X, y, probability=True):
 
 
 def create_sklearn_logistic_regressor(X, y, pipeline=False):
-    lin = LogisticRegression(solver='liblinear')
+    lin = LogisticRegression(solver='liblinear', random_state=777)
     if pipeline:
         lin = Pipeline([('lin', lin)])
     model = lin.fit(X, y)
@@ -91,7 +91,7 @@ def create_cancer_data():
 
 
 def create_binary_classification_dataset():
-    X, y = make_classification()
+    X, y = make_classification(random_state=777)
 
     # Split data into train and test
     X_train, X_test, y_train, y_test = train_test_split(X,
@@ -127,7 +127,7 @@ def create_adult_income_dataset():
     # Split data into train and test
     data_train, data_test, y_train, y_test = train_test_split(
         dataset, target,
-        test_size=0.2, random_state=7, stratify=target)
+        test_size=5000, random_state=7, stratify=target)
     return data_train, data_test, y_train, y_test, categorical_features, \
         continuous_features, target_name, classes
 
